@@ -138,7 +138,7 @@ class Base(Mixin, ABC):
     def _validate_secret(
         self,
         secret: typing.Union[Secret, typing.Sequence[Secret]],
-    ) -> typing.Tuple[bytes, ...]:
+    ) -> tuple[bytes, ...]:
         """Validate the secret value and return it clean.
 
         Args:
@@ -264,12 +264,12 @@ class Base(Mixin, ABC):
     def _get_hasher(
         hasher: HasherChoice,
         *,
-        secrets: typing.Tuple[bytes, ...],
+        secrets: tuple[bytes, ...],
         digest_size: int,
         person: bytes,
     ) -> BLAKEHasher:
         """Get the proper hasher instance regarding the choice."""
-        hasher_class: typing.Type[BLAKEHasher]
+        hasher_class: type[BLAKEHasher]
 
         if hasher in {HasherChoice.blake2b, HasherChoice.blake2s}:
             hasher_class = BLAKE2Hasher
@@ -287,62 +287,6 @@ class Base(Mixin, ABC):
 class Blake2SignerBase(EncoderMixin, Base, ABC):
     """Base class for a signer based on BLAKE in keyed hashing mode."""
 
-    def __init__(  # pylint: disable=W0235  # Not useless, otherwise I lose hints and docs.
-        self,
-        secret: typing.Union[Secret, typing.Sequence[Secret]],
-        *,
-        personalisation: typing.Union[str, bytes] = b'',
-        digest_size: typing.Optional[int] = None,
-        hasher: typing.Union[HasherChoice, str] = HasherChoice.blake2b,
-        deterministic: bool = False,
-        separator: typing.Union[str, bytes] = b'.',
-        encoder: typing.Type[EncoderInterface] = B64URLEncoder,
-    ) -> None:
-        """Sign and verify signed data using BLAKE in keyed hashing mode.
-
-        Args:
-            secret: Secret value, which will be derived using BLAKE to produce the
-                signing key. The minimum secret size is enforced to 16 bytes, and there
-                is no maximum. You can optionally provide a sequence of secrets, oldest
-                to newest, that are used during signature check to allow for secret
-                rotation. The last, newest, secret is used for signing.
-
-        Keyword Args:
-            personalisation (optional): Personalisation string to force the hash
-                function to produce different digests for the same input. It is
-                derived using BLAKE to ensure it fits the hasher limits, so it
-                has no practical size limit. It defaults to the class name.
-            digest_size (optional): Size of output signature (digest) in bytes
-                (defaults to 16 bytes). The minimum size is enforced to 16 bytes.
-            hasher (optional): Hash function to use: blake2b (default), blake2s
-                or blake3.
-            deterministic (optional): Define if signatures are deterministic or
-                non-deterministic (default). Non-deterministic sigs are preferred
-                and achieved through the use of a random salt. For deterministic
-                sigs, no salt is used: this means that the result is idempotent, so
-                for the same payload, the same sig is obtained (the advantage is
-                that the sig is shorter, and producing it is faster).
-            separator (optional): Character to separate the signature and the
-                payload. It must not belong to the encoder alphabet and be ASCII
-                (defaults to ".").
-            encoder (optional): Encoder class to use for the signature, nothing
-                else is encoded (defaults to a Base64 URL-safe encoder).
-
-        Raises:
-            ConversionError: A bytes parameter is not bytes and can't be converted
-                to bytes.
-            InvalidOptionError: A parameter is out of bounds.
-        """
-        super().__init__(
-            secret,
-            personalisation=personalisation,
-            digest_size=digest_size,
-            hasher=hasher,
-            separator=separator,
-            deterministic=deterministic,
-            encoder=encoder,
-        )
-
     def _validate_separator(self, separator: typing.Union[str, bytes]) -> bytes:
         """Validate the separator value and return it clean.
 
@@ -633,7 +577,7 @@ class Blake2DualSignerBase(Blake2TimestampSignerBase, ABC):
         hasher: typing.Union[HasherChoice, str] = HasherChoice.blake2b,
         deterministic: bool = False,
         separator: typing.Union[str, bytes] = b'.',
-        encoder: typing.Type[EncoderInterface] = B64URLEncoder,
+        encoder: type[EncoderInterface] = B64URLEncoder,
     ) -> None:
         """Sign and verify signed and optionally timestamped data using BLAKE.
 
