@@ -386,9 +386,9 @@ class Blake2SerializerSigner(
         hasher: typing.Union[HasherChoice, str] = HasherChoice.blake2b,
         deterministic: bool = False,
         separator: typing.Union[str, bytes] = b'.',
-        encoder: typing.Type[EncoderInterface] = B64URLEncoder,
-        serializer: typing.Type[SerializerInterface] = JSONSerializer,
-        compressor: typing.Type[CompressorInterface] = ZlibCompressor,
+        encoder: type[EncoderInterface] = B64URLEncoder,
+        serializer: type[SerializerInterface] = JSONSerializer,
+        compressor: type[CompressorInterface] = ZlibCompressor,
         compression_flag: typing.Union[str, bytes] = b'.',
         compression_ratio: typing.Union[int, float] = 5.0,
     ) -> None:
@@ -492,7 +492,7 @@ class Blake2SerializerSigner(
         compress: bool = kwargs['compress']
         compression_level: typing.Optional[int] = kwargs.get('compression_level')
         force_compression: bool = kwargs['force_compression']
-        serializer_kwargs: typing.Dict[str, typing.Any] = kwargs.get('serializer_kwargs') or {}
+        serializer_kwargs: dict[str, typing.Any] = kwargs.get('serializer_kwargs') or {}
 
         serialized = self._serialize(data, **serializer_kwargs)
 
@@ -531,7 +531,7 @@ class Blake2SerializerSigner(
             DecompressionError: Data can't be decompressed.
             UnserializationError: Data can't be unserialized.
         """
-        serializer_kwargs: typing.Dict[str, typing.Any] = kwargs.get('serializer_kwargs') or {}
+        serializer_kwargs: dict[str, typing.Any] = kwargs.get('serializer_kwargs') or {}
 
         data, is_compressed = self._remove_compression_flag_if_compressed(dumped_data)
 
@@ -550,7 +550,7 @@ class Blake2SerializerSigner(
         compress: bool = True,
         compression_level: typing.Optional[int] = None,
         force_compression: bool = False,
-        serializer_kwargs: typing.Optional[typing.Dict[str, typing.Any]] = None,
+        serializer_kwargs: typing.Optional[dict[str, typing.Any]] = None,
     ) -> str:
         """Serialize and sign data, optionally compressing and/or timestamping it.
 
@@ -623,7 +623,7 @@ class Blake2SerializerSigner(
         compress: bool = True,
         compression_level: typing.Optional[int] = None,
         force_compression: bool = False,
-        serializer_kwargs: typing.Optional[typing.Dict[str, typing.Any]] = None,
+        serializer_kwargs: typing.Optional[dict[str, typing.Any]] = None,
     ) -> Blake2SignatureDump:
         """Serialize and sign data, optionally compressing and/or timestamping it.
 
@@ -705,7 +705,7 @@ class Blake2SerializerSigner(
         compress: bool = True,
         compression_level: typing.Optional[int] = None,
         force_compression: bool = False,
-        serializer_kwargs: typing.Optional[typing.Dict[str, typing.Any]] = None,
+        serializer_kwargs: typing.Optional[dict[str, typing.Any]] = None,
     ) -> str:
         """Serialize and sign data to file optionally compressing and/or timestamping it.
 
@@ -785,7 +785,7 @@ class Blake2SerializerSigner(
         self,
         signed_data: typing.Union[str, bytes],
         *,
-        serializer_kwargs: typing.Optional[typing.Dict[str, typing.Any]] = None,
+        serializer_kwargs: typing.Optional[dict[str, typing.Any]] = None,
     ) -> typing.Any:
         """Recover original data from a signed serialized string from `dumps`.
 
@@ -824,7 +824,7 @@ class Blake2SerializerSigner(
         self,
         signature: typing.Union[Blake2Signature, Blake2SignatureDump],
         *,
-        serializer_kwargs: typing.Optional[typing.Dict[str, typing.Any]] = None,
+        serializer_kwargs: typing.Optional[dict[str, typing.Any]] = None,
     ) -> typing.Any:
         """Recover original data from a signed serialized container from `dumps_parts`.
 
@@ -868,7 +868,7 @@ class Blake2SerializerSigner(
         self,
         file: typing.IO[typing.AnyStr],
         *,
-        serializer_kwargs: typing.Optional[typing.Dict[str, typing.Any]] = None,
+        serializer_kwargs: typing.Optional[dict[str, typing.Any]] = None,
     ) -> typing.Any:
         """Recover original data from a signed serialized file from `dump`.
 
