@@ -47,7 +47,7 @@ class BaseTests(ABC):
 
     @property
     @abstractmethod
-    def signer_class(self) -> typing.Type[Signer]:
+    def signer_class(self) -> type[Signer]:
         """Get the signer class to test."""
 
     def signer(
@@ -60,7 +60,7 @@ class BaseTests(ABC):
 
     @property
     @abstractmethod
-    def signature_type(self) -> typing.Type[typing.Union[str, bytes]]:
+    def signature_type(self) -> type[typing.Union[str, bytes]]:
         """Get the signature type for the signer, either `str` or `bytes`."""
 
     @typing.overload
@@ -228,7 +228,7 @@ class BaseTests(ABC):
         return signer._compose(data_b, signature=signer._sign(data_b))  # pylint: disable=W0212
 
     @pytest.fixture
-    def signer_min_digest_size_changed(self) -> typing.Type[Signer]:
+    def signer_min_digest_size_changed(self) -> type[Signer]:
         """Fixture to obtain a signer class with a non-default min digest size limit."""
         signer_class = self.signer_class
         min_digest_size = signer_class.MIN_DIGEST_SIZE
@@ -239,7 +239,7 @@ class BaseTests(ABC):
         signer_class.MIN_DIGEST_SIZE = min_digest_size
 
     @pytest.fixture
-    def signer_min_secret_size_changed(self) -> typing.Type[Signer]:
+    def signer_min_secret_size_changed(self) -> type[Signer]:
         """Fixture to obtain a signer class with a non-default min secret size limit."""
         signer_class = self.signer_class
         min_secret_size = signer_class.MIN_SECRET_SIZE
@@ -296,7 +296,7 @@ class BaseTests(ABC):
     def test_hasher_can_be_changed(
         self,
         hasher: HasherChoice,
-        hasher_class: typing.Type[BLAKEHasher],
+        hasher_class: type[BLAKEHasher],
     ) -> None:
         """Test that the hasher can be changed and works correctly."""
         signer = self.signer(hasher=hasher)
@@ -612,7 +612,7 @@ class BaseTests(ABC):
     )
     def test_sign_unsign_with_encoder(
         self,
-        encoder: typing.Type[EncoderInterface],
+        encoder: type[EncoderInterface],
         regex: str,
         hasher: HasherChoice,
     ) -> None:
@@ -880,7 +880,7 @@ class BaseTests(ABC):
     )
     def test_separator_in_encoder_alphabet(
         self,
-        encoder: typing.Type[EncoderInterface],
+        encoder: type[EncoderInterface],
         separator: bytes,
         hasher: HasherChoice,
     ) -> None:
