@@ -42,12 +42,12 @@ class SerializerSignerTestsBase(BaseTests, ABC):
     data_incompressible = token_bytes(10).hex()  # so it can't be compressed
 
     @property
-    def signer_class(self) -> typing.Type[Signer]:
+    def signer_class(self) -> type[Signer]:
         """Get the signer class to test."""
         return Blake2SerializerSigner
 
     @property
-    def signature_type(self) -> typing.Type[typing.Union[str, bytes]]:
+    def signature_type(self) -> type[typing.Union[str, bytes]]:
         """Get the signature type for the signer (`str`)."""
         return str
 
@@ -161,7 +161,7 @@ class SerializerSignerTestsBase(BaseTests, ABC):
     )
     def test_sign_unsign_with_encoder(
         self,
-        encoder: typing.Type[EncoderInterface],
+        encoder: type[EncoderInterface],
         regex: str,
         hasher: HasherChoice,
     ) -> None:
@@ -526,7 +526,7 @@ class SerializerSignerTestsBase(BaseTests, ABC):
     )
     def test_dumps_loads_with_compressor(
         self,
-        compressor: typing.Type[CompressorInterface],
+        compressor: type[CompressorInterface],
         hasher: HasherChoice,
     ) -> None:
         """Test dumping and loading using a compressor."""
@@ -596,7 +596,7 @@ class SerializerSignerTestsBase(BaseTests, ABC):
     )
     def test_dump_load_file(
         self,
-        file_class: typing.Type[typing.IO[typing.AnyStr]],
+        file_class: type[typing.IO[typing.AnyStr]],
         hasher: HasherChoice,
     ) -> None:
         """Test dumping and loading to/from a file."""
@@ -635,7 +635,7 @@ class SerializerSignerTestsBase(BaseTests, ABC):
     )
     def test_dump_load_file_with_null_serializer(
         self,
-        file_class: typing.Type[typing.IO[typing.AnyStr]],
+        file_class: type[typing.IO[typing.AnyStr]],
         hasher: HasherChoice,
     ) -> None:
         """Test dumping and loading to/from a file."""
@@ -675,7 +675,7 @@ class SerializerSignerTestsBase(BaseTests, ABC):
     )
     def test_dump_load_file_containing_data(
         self,
-        file_class: typing.Type[typing.IO[typing.AnyStr]],
+        file_class: type[typing.IO[typing.AnyStr]],
         initial_data: typing.Union[str, bytes],
         hasher: HasherChoice,
     ) -> None:
@@ -1273,7 +1273,7 @@ class SerializerSignerTestsBase(BaseTests, ABC):
     )
     def test_compression_flag_in_encoder_alphabet(
         self,
-        encoder: typing.Type[EncoderInterface],
+        encoder: type[EncoderInterface],
         flag: bytes,
         hasher: HasherChoice,
     ) -> None:
